==> openshift-model-operator-5.12.4-sources.jar: io/fabric8/openshift/api/model/operator/v1/CloudCredentialBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CloudCredentialBuilder extends io.fabric8.openshift.api.model.operator.v1.CloudCredentialFluentImpl<io.fabric8.openshift.api.model.operator.v1.CloudCredentialBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.operator.v1.CloudCredential,io.fabric8.openshift.api.model.operator.v1.CloudCredentialBuilder>{
  public CloudCredentialBuilder() {
    this(false);
  }
  public CloudCredentialBuilder(java.lang.Boolean validationEnabled) {
    this(new CloudCredential(), validationEnabled);
  }
  public CloudCredentialBuilder(io.fabric8.openshift.api.model.operator.v1.CloudCredentialFluent<?> fluent) {
    this(fluent, false);
  }
  public CloudCredentialBuilder(io.fabric8.openshift.api.model.operator.v1.CloudCredentialFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CloudCredential(), validationEnabled);
  }
  public CloudCredentialBuilder(io.fabric8.openshift.api.model.operator.v1.CloudCredentialFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.CloudCredential instance) {
    this(fluent, instance, false);
  }
  public CloudCredentialBuilder(io.fabric8.openshift.api.model.operator.v1.CloudCredentialFluent<?> fluent,io.fabric8.openshift.api.model.operator.v1.CloudCredential instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CloudCredentialBuilder(io.fabric8.openshift.api.model.operator.v1.CloudCredential instance) {
    this(instance,false);
  }
  public CloudCredentialBuilder(io.fabric8.openshift.api.model.operator.v1.CloudCredential instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.operator.v1.CloudCredentialFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.operator.v1.CloudCredential build() {
    CloudCredential buildable = new CloudCredential(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CloudCredentialBuilder that = (CloudCredentialBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-operator-6.5.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/CloudCredentialBuilder.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class CloudCredentialBuilder extends CloudCredentialFluentImpl<CloudCredentialBuilder> implements VisitableBuilder<CloudCredential,CloudCredentialBuilder>{
  public CloudCredentialBuilder() {
    this(false);
  }
  public CloudCredentialBuilder(Boolean validationEnabled) {
    this(new CloudCredential(), validationEnabled);
  }
  public CloudCredentialBuilder(CloudCredentialFluent<?> fluent) {
    this(fluent, false);
  }
  public CloudCredentialBuilder(CloudCredentialFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new CloudCredential(), validationEnabled);
  }
  public CloudCredentialBuilder(CloudCredentialFluent<?> fluent,CloudCredential instance) {
    this(fluent, instance, false);
  }
  public CloudCredentialBuilder(CloudCredentialFluent<?> fluent,CloudCredential instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CloudCredentialBuilder(CloudCredential instance) {
    this(instance,false);
  }
  public CloudCredentialBuilder(CloudCredential instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  CloudCredentialFluent<?> fluent;
  Boolean validationEnabled;
  public CloudCredential build() {
    CloudCredential buildable = new CloudCredential(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
